import { BaseHarnessFilters, ContentContainerComponentHarness, HarnessPredicate } from '@angular/cdk/testing';
import { DialogButtonColor } from './dialog.component';
interface SlDialogHarnessFilters extends BaseHarnessFilters {
    title?: RegExp | string;
}
/**
 * Harness for interacting with a dialog opened via {@link SlDialogService.open}.
 */
export declare class SlDialogHarness extends ContentContainerComponentHarness {
    #private;
    static hostSelector: string;
    /**
     * Gets a `HarnessPredicate` that can be used to search for a SlDialogHarness that meets certain criteria.
     */
    static with(options: SlDialogHarnessFilters): HarnessPredicate<SlDialogHarness>;
    getTitle(): Promise<string>;
    /**
     * Get the text displayed in the content of the dialog. Note this includes text from both the `text` and `component` options of {@link SlDialogService.open}.
     */
    getContentText(): Promise<string>;
    /**
     * Return the text of all the buttons.
     */
    getButtonText(): Promise<string[]>;
    /**
     * Return the text of all the buttons. Note that "default" corresponds to when you explicitly specify that color for the button, and is **not** the color of a button when you don't specify a color (see {@link DialogButton.color}).
     */
    getButtonColors(): Promise<DialogButtonColor[]>;
    clickButton(text: string): Promise<void>;
    /**
     * Closes the dialog by pressing escape.
     */
    close(): Promise<void>;
}
export {};
